..
  This file is auto-generated.


.. _api:

Developer API
=============

.. toctree::
   :caption: API
   :maxdepth: 1

.. autosummary::
   :toctree: api

   das.annot
   das.augmentation
   das.block_stratify
   das.data
   das.data_hash
   das.evaluate
   das.event_utils
   das.io
   das.make_dataset
   das.menagerie
   das.models
   das.models_legacy
   das.npy_dir
   das.postprocessing
   das.predict
   das.pulse_utils
   das.segment_utils
   das.spec_utils
   das.tracking
   das.train
   das.train_tune
   das.utils
   das.utils_plot
   das.tcn.tcn
   das.tcn.tcn_new
   das.kapre.augmentation
   das.kapre.backend
   das.kapre.backend_keras
   das.kapre.filterbank
   das.kapre.time_frequency
   das.kapre.utils
